/*
 * Dice.kt
 *
 * Copyright (c) 2004-2021, Erik C. Thauvin (erik@thauvin.net)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *   Redistributions of source code must retain the above copyright notice, this
 *   list of conditions and the following disclaimer.
 *
 *   Redistributions in binary form must reproduce the above copyright notice,
 *   this list of conditions and the following disclaimer in the documentation
 *   and/or other materials provided with the distribution.
 *
 *   Neither the name of this project nor the names of its contributors may be
 *   used to endorse or promote products derived from this software without
 *   specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package net.thauvin.erik.mobibot.modules

import net.thauvin.erik.mobibot.Mobibot
import net.thauvin.erik.mobibot.Utils.bold
import net.thauvin.erik.mobibot.Utils.helpFormat
import kotlin.random.Random

/**
 * The Dice module.
 */
class Dice(bot: Mobibot) : AbstractModule(bot) {
    override fun commandResponse(
        sender: String,
        cmd: String,
        args: String,
        isPrivate: Boolean
    ) {
        val roll = roll()
        val playerRoll = roll()
        val total = roll.first + roll.second
        val playerTotal = playerRoll.first + playerRoll.second
        with(bot) {
            send(
                channel,
                "$sender rolled two dice: ${bold(playerRoll.first)} and ${bold(playerRoll.second)}"
                    + " for a total of ${bold(playerTotal)}",
                isPrivate
            )
            action(
                "rolled two dice: ${bold(roll.first)} and ${bold(roll.second)}" +
                    " for a total of ${bold(total)}"
            )
            when (winLoseOrTie(total, playerTotal)) {
                Result.WIN -> action("wins.")
                Result.LOSE -> action("lost.")
                else -> action("tied.")
            }
        }
    }

    enum class Result {
        WIN, LOSE, TIE
    }

    private fun roll(): Pair<Int, Int> {
        @Suppress("MagicNumber")
        return Pair(Random.nextInt(1, 7), Random.nextInt(1, 7))
    }

    companion object {
        // Dice command
        private const val DICE_CMD = "dice"

        fun winLoseOrTie(bot: Int, player: Int): Result {
            return when {
                bot > player -> {
                    Result.WIN
                }
                bot < player -> {
                    Result.LOSE
                }
                else -> {
                    Result.TIE
                }
            }
        }
    }

    init {
        commands.add(DICE_CMD)
        help.add("To roll the dice:")
        help.add(helpFormat("%c $DICE_CMD"))
    }
}
